@@ -3,6 +3,8 @@ from PyObjCTools import AppHelper
 import CIMicroPaintView
 import SampleCIView
 
-import objc; objc.setVerbose(True)
+import objc
+
+objc.setVerbose(True)
 
 AppHelper.runEventLoop()
