@@ -3,23 +3,28 @@ import Utilities
 
 import sys
 
+
 def scalePatternPhase(phase):
     # Adjust the pattern phase if scaling to export as bits. This is equivalent to scaling base
     # space by the scaling factor.
     patternScaling = Utilities.getScalingFactor()
     if patternScaling != 1.0:
-        phase = Quartz.CGSizeApplyAffineTransform(phase,
-            Quartz.CGAffineTransformMakeScale(patternScaling, patternScaling))
+        phase = Quartz.CGSizeApplyAffineTransform(
+            phase, Quartz.CGAffineTransformMakeScale(patternScaling, patternScaling)
+        )
 
     return phase
 
+
 def scalePatternMatrix(patternTransform):
     # Scale the pattern by the scaling factor when exporting to bits. This is equivalent to
     # scaling base space by the scaling factor.
     patternScaling = Utilities.getScalingFactor()
     if patternScaling != 1.0:
-        patternTransform = Quartz.CGAffineTransformConcat(patternTransform,
-                Quartz.CGAffineTransformMakeScale(patternScaling, patternScaling))
+        patternTransform = Quartz.CGAffineTransformConcat(
+            patternTransform,
+            Quartz.CGAffineTransformMakeScale(patternScaling, patternScaling),
+        )
 
     return patternTransform
 
@@ -33,20 +38,22 @@ def myDrawRedBlackCheckerBoardPattern(info, patternCellContext):
     #
     # This code uses Quartz.CGColorRefs which are available in Panther
     # and later only. Patterns are available in all versions of
-    # Mac OS X but this code uses Quartz.CGColorRefs for convenience
+    # macOS but this code uses Quartz.CGColorRefs for convenience
     # and efficiency.
 
     # Paint a black checkerboard box.
-    Quartz.CGContextSetFillColorWithColor(patternCellContext,
-            Utilities.getRGBOpaqueBlackColor())
+    Quartz.CGContextSetFillColorWithColor(
+        patternCellContext, Utilities.getRGBOpaqueBlackColor()
+    )
     # This is a 1x1 unit rect whose origin is at 0,0 in pattern space.
     Quartz.CGContextFillRect(patternCellContext, Quartz.CGRectMake(0.0, 0.0, 1.0, 1.0))
     # This is a 1x1 unit rect whose origin is at 1,1 in pattern space.
     Quartz.CGContextFillRect(patternCellContext, Quartz.CGRectMake(1.0, 1.0, 1.0, 1.0))
 
     # Paint a red checkerboard box.
-    Quartz.CGContextSetFillColorWithColor(patternCellContext,
-            Utilities.getRGBOpaqueRedColor())
+    Quartz.CGContextSetFillColorWithColor(
+        patternCellContext, Utilities.getRGBOpaqueRedColor()
+    )
     # This is a 1x1 unit rect whose origin is at 1,0 in pattern space,
     # that is, immediately to the right of first black checkerboard box.
     Quartz.CGContextFillRect(patternCellContext, Quartz.CGRectMake(1.0, 0.0, 1.0, 1.0))
@@ -54,8 +61,10 @@ def myDrawRedBlackCheckerBoardPattern(info, patternCellContext):
     # that is, immediately above the first black checkerboard box.
     Quartz.CGContextFillRect(patternCellContext, Quartz.CGRectMake(0.0, 1.0, 1.0, 1.0))
 
+
 def createRedBlackCheckerBoardPattern(patternTransform):
-    pattern = Quartz.CGPatternCreate(None,
+    pattern = Quartz.CGPatternCreate(
+        None,
         # The pattern cell origin is at (0,0) with a
         # width of 2 units and a height of 2 units.
         Quartz.CGRectMake(0, 0, 2, 2),
@@ -63,20 +72,21 @@ def createRedBlackCheckerBoardPattern(patternTransform):
         scalePatternMatrix(patternTransform),
         # In pattern space the xStep is 2 units to the next cell in x
         # and the yStep is 2 units to the next row of cells in y.
-        2, 2,
+        2,
+        2,
         # This value is a good choice for this type of pattern and it
         # avoids seams between tiles.
         Quartz.kCGPatternTilingConstantSpacingMinimalDistortion,
         # This pattern has intrinsic color.
         True,
         myDrawRedBlackCheckerBoardPattern,
-        )
+    )
     return pattern
 
+
 def doRedBlackCheckerboard(context):
     dash = [4]
-    pattern = createRedBlackCheckerBoardPattern(
-                            Quartz.CGAffineTransformMakeScale(20, 20))
+    pattern = createRedBlackCheckerBoardPattern(Quartz.CGAffineTransformMakeScale(20, 20))
     if pattern is None:
         print("Couldn't create pattern!")
         return
@@ -110,7 +120,9 @@ def doRedBlackCheckerboard(context):
         # Stroke an ellipse with the pattern.
         Quartz.CGContextSetLineWidth(context, 8)
         Quartz.CGContextBeginPath(context)
-        Utilities.myCGContextAddEllipseInRect(context, Quartz.CGRectMake(120, 20, 50, 100))
+        Utilities.myCGContextAddEllipseInRect(
+            context, Quartz.CGRectMake(120, 20, 50, 100)
+        )
         Quartz.CGContextStrokePath(context)
 
     # Restore to the graphics state without the
@@ -139,6 +151,7 @@ def doRedBlackCheckerboard(context):
     Quartz.CGContextAddRect(context, Quartz.CGRectMake(200, 70, 90, 90))
     Quartz.CGContextDrawPath(context, Quartz.kCGPathFillStroke)
 
+
 def doPatternMatrix(context):
     basePatternMatrix = Quartz.CGAffineTransformMakeScale(20, 20)
     pattern = createRedBlackCheckerBoardPattern(basePatternMatrix)
@@ -233,8 +246,7 @@ def doPatternMatrix(context):
 
 
 def doPatternPhase(context):
-    pattern = createRedBlackCheckerBoardPattern(
-                            Quartz.CGAffineTransformMakeScale(20, 20))
+    pattern = createRedBlackCheckerBoardPattern(Quartz.CGAffineTransformMakeScale(20, 20))
     if pattern is None:
         print("Couldn't create pattern!")
         return
@@ -256,51 +268,59 @@ def doPatternPhase(context):
     # Rectangle 3
     # Set the pattern phase so that the pattern origin
     # is at the lower-left of the shape.
-    Quartz.CGContextSetPatternPhase(context, scalePatternPhase( Quartz.CGSizeMake(20, 20) ))
+    Quartz.CGContextSetPatternPhase(context, scalePatternPhase(Quartz.CGSizeMake(20, 20)))
     Quartz.CGContextFillRect(context, Quartz.CGRectMake(20, 20, 100, 100))
 
     # Rectangle 4
     # Set the pattern phase so that the pattern origin
     # is at the lower-left corner of the shape.
-    Quartz.CGContextSetPatternPhase(context, scalePatternPhase( Quartz.CGSizeMake(130, 20) ))
+    Quartz.CGContextSetPatternPhase(
+        context, scalePatternPhase(Quartz.CGSizeMake(130, 20))
+    )
     Quartz.CGContextTranslateCTM(context, 130, 20)
     Quartz.CGContextFillRect(context, Quartz.CGRectMake(0, 0, 100, 100))
 
+
 def drawRotatedRect(c, p):
     r = Quartz.CGRectMake(0, 0, 1, 1)
     Quartz.CGContextSaveGState(c)
     if 1:
         Quartz.CGContextTranslateCTM(c, p.x, p.y)
         Quartz.CGContextRotateCTM(c, Utilities.DEGREES_TO_RADIANS(45))
-        Quartz.CGContextTranslateCTM(c, -r.size.width/2, -r.size.height/2)
+        Quartz.CGContextTranslateCTM(c, -r.size.width / 2, -r.size.height / 2)
         Quartz.CGContextFillRect(c, r)
     Quartz.CGContextRestoreGState(c)
 
+
 def myStencilPatternProc(info, patternCellContext):
     drawRotatedRect(patternCellContext, Quartz.CGPointMake(1, 1))
     drawRotatedRect(patternCellContext, Quartz.CGPointMake(1.75, 1))
 
+
 def createStencilPattern(patternTransform):
-    pattern = Quartz.CGPatternCreate(None,
-                # The pattern cell origin is at (0,0) with a
-                # width of 2.5 units and a height of 2 units. This
-                # pattern cell has transparent areas since
-                # the pattern proc only marks a portion of the cell.
-                Quartz.CGRectMake(0, 0, 2.5, 2),
-                # Use the pattern transform supplied to this routine.
-                scalePatternMatrix(patternTransform),
-                # Use the width and height of the pattern cell for
-                # the xStep and yStep.
-                2.5, 2,
-                # This value is a good choice for this type of pattern and it
-                # avoids seams between tiles.
-                Quartz.kCGPatternTilingConstantSpacingMinimalDistortion,
-                # This pattern does not have intrinsic color.
-                False,   # Must be False for a stencil pattern.
-                myStencilPatternProc,
-                )
+    pattern = Quartz.CGPatternCreate(
+        None,
+        # The pattern cell origin is at (0,0) with a
+        # width of 2.5 units and a height of 2 units. This
+        # pattern cell has transparent areas since
+        # the pattern proc only marks a portion of the cell.
+        Quartz.CGRectMake(0, 0, 2.5, 2),
+        # Use the pattern transform supplied to this routine.
+        scalePatternMatrix(patternTransform),
+        # Use the width and height of the pattern cell for
+        # the xStep and yStep.
+        2.5,
+        2,
+        # This value is a good choice for this type of pattern and it
+        # avoids seams between tiles.
+        Quartz.kCGPatternTilingConstantSpacingMinimalDistortion,
+        # This pattern does not have intrinsic color.
+        False,  # Must be False for a stencil pattern.
+        myStencilPatternProc,
+    )
     return pattern
 
+
 def doStencilPattern(context):
     pattern = createStencilPattern(Quartz.CGAffineTransformMakeScale(20, 20))
     if pattern is None:
@@ -329,7 +349,9 @@ def doStencilPattern(context):
     Quartz.CGContextSetFillPattern(context, pattern, color)
 
     # Rectangle 1.
-    Quartz.CGContextSetPatternPhase(context, scalePatternPhase( Quartz.CGSizeMake(20, 160) ))
+    Quartz.CGContextSetPatternPhase(
+        context, scalePatternPhase(Quartz.CGSizeMake(20, 160))
+    )
     Quartz.CGContextBeginPath(context)
     Quartz.CGContextAddRect(context, Quartz.CGRectMake(20, 160, 105, 80))
     Quartz.CGContextDrawPath(context, Quartz.kCGPathFillStroke)
@@ -340,15 +362,16 @@ def doStencilPattern(context):
     color = (1.0, 0.816, 0.0, 1.0)
     Quartz.CGContextSetFillPattern(context, pattern, color)
     # Set the pattern phase to the origin of the next object.
-    Quartz.CGContextSetPatternPhase(context, scalePatternPhase( Quartz.CGSizeMake(140, 160) ))
+    Quartz.CGContextSetPatternPhase(
+        context, scalePatternPhase(Quartz.CGSizeMake(140, 160))
+    )
     Quartz.CGContextBeginPath(context)
     Quartz.CGContextAddRect(context, Quartz.CGRectMake(140, 160, 105, 80))
     Quartz.CGContextDrawPath(context, Quartz.kCGPathFillStroke)
 
     Quartz.CGContextSaveGState(context)
     if 1:
-        Quartz.CGContextSetFillColorWithColor(context,
-                Utilities.getRGBOpaqueBlueColor())
+        Quartz.CGContextSetFillColorWithColor(context, Utilities.getRGBOpaqueBlueColor())
         # Fill color is now blue. Paint two blue rectangles
         # that will be underneath the drawing which follows.
         Quartz.CGContextFillRect(context, Quartz.CGRectMake(20, 40, 105, 80))
@@ -362,7 +385,7 @@ def doStencilPattern(context):
     # This paints over the blue rect just painted at 20,40
     # and the blue underneath is visible where the pattern has
     # transparent areas.
-    Quartz.CGContextSetPatternPhase(context, scalePatternPhase( Quartz.CGSizeMake(20, 40) ))
+    Quartz.CGContextSetPatternPhase(context, scalePatternPhase(Quartz.CGSizeMake(20, 40)))
     Quartz.CGContextFillRect(context, Quartz.CGRectMake(20, 40, 105, 80))
 
     # Rectangle 4.
@@ -371,13 +394,17 @@ def doStencilPattern(context):
     color = list(color)
     color[3] = 0.75
     Quartz.CGContextSetFillPattern(context, pattern, color)
-    Quartz.CGContextSetPatternPhase(context, scalePatternPhase( Quartz.CGSizeMake(140, 40) ))
+    Quartz.CGContextSetPatternPhase(
+        context, scalePatternPhase(Quartz.CGSizeMake(140, 40))
+    )
     Quartz.CGContextFillRect(context, Quartz.CGRectMake(140, 40, 105, 80))
 
-class MyPDFPatternInfo (object):
+
+class MyPDFPatternInfo(object):
     rect = None
     pdfDoc = None
 
+
 def myDrawPDFPattern(info, patternCellContext):
     # This pattern proc draws the first page of a PDF document to
     # a destination rect.
@@ -386,15 +413,16 @@ def myDrawPDFPattern(info, patternCellContext):
     Quartz.CGContextDrawPDFDocument(patternCellContext, info.rect, info.pdfDoc, 1)
     Quartz.CGContextRestoreGState(patternCellContext)
 
+
 # Versions of Tiger prior to 10.4.3 have a bug such that use of an xStep that
 # doesn't match the width of pattern bounding box or a yStep that doesn't match the
 # height of the pattern bounding box produces incorrect results when drawn
 # to a bit-based context. Setting TIGERSTEPWORKAROUND works around this bug.
 
 
-TIGERSTEPWORKAROUND=1
-SCALEPATTERN=1
-OPTIMIZEDPERF=0
+TIGERSTEPWORKAROUND = 1
+SCALEPATTERN = 1
+OPTIMIZEDPERF = 0
 
 
 def createPDFPatternPattern(additionalTransformP, url):
@@ -418,11 +446,11 @@ def createPDFPatternPattern(additionalTransformP, url):
     # the tile offset in each dimension is the tile size in that
     # dimension, plus 6 units.
     if SCALEPATTERN:
-        tileOffsetX = 6. + patternInfoP.rect.size.width
-        tileOffsetY = 6. + patternInfoP.rect.size.height
+        tileOffsetX = 6.0 + patternInfoP.rect.size.width
+        tileOffsetY = 6.0 + patternInfoP.rect.size.height
     else:
-        tileOffsetX = 2. + patternInfoP.rect.size.width
-        tileOffsetY = 2. + patternInfoP.rect.size.height
+        tileOffsetX = 2.0 + patternInfoP.rect.size.width
+        tileOffsetY = 2.0 + patternInfoP.rect.size.height
 
     # Tiger versions 10.4.0 - 10.4.2 have a bug such that the bounds
     # width and height is incorrectly used as the xstep,ystep.
@@ -439,19 +467,21 @@ def createPDFPatternPattern(additionalTransformP, url):
     else:
         spacing = Quartz.kCGPatternTilingConstantSpacingMinimalDistortion
 
-    pattern = Quartz.CGPatternCreate(patternInfoP,
-            # The pattern cell size is the size
-            # of the media rect of the PDF document.
-            patternRect,
-            scalePatternMatrix(patternTransform),
-            tileOffsetX, tileOffsetY,
-            # This value is a good choice for this type of pattern and
-            #  it avoids seams between tiles.
-            spacing,
-            # This pattern has intrinsic color.
-            True,
-            myDrawPDFPattern,
-            )
+    pattern = Quartz.CGPatternCreate(
+        patternInfoP,
+        # The pattern cell size is the size
+        # of the media rect of the PDF document.
+        patternRect,
+        scalePatternMatrix(patternTransform),
+        tileOffsetX,
+        tileOffsetY,
+        # This value is a good choice for this type of pattern and
+        #  it avoids seams between tiles.
+        spacing,
+        # This pattern has intrinsic color.
+        True,
+        myDrawPDFPattern,
+    )
     # If the pattern can't be created then release the
     # pattern resources and info parameter.
     if pattern is None:
@@ -462,7 +492,7 @@ def createPDFPatternPattern(additionalTransformP, url):
 
 def drawWithPDFPattern(context, url):
     if SCALEPATTERN:
-        patternMatrix = Quartz.CGAffineTransformMakeScale(1.0/3, 1.0/3)
+        patternMatrix = Quartz.CGAffineTransformMakeScale(1.0 / 3, 1.0 / 3)
     else:
         patternMatrix = Quartz.CGAffineTransformMakeScale(1, 1)
 
