@@ -1,8 +1,8 @@
-
 from PyObjCTools.TestSupport import *
 from Quartz.PDFKit import *
 
-class TestPDFBorder (TestCase):
+
+class TestPDFBorder(TestCase):
     def testConstants(self):
         self.assertEqual(kPDFBorderStyleSolid, 0)
         self.assertEqual(kPDFBorderStyleDashed, 1)
@@ -10,11 +10,12 @@ class TestPDFBorder (TestCase):
         self.assertEqual(kPDFBorderStyleInset, 3)
         self.assertEqual(kPDFBorderStyleUnderline, 4)
 
-    @min_os_level('10.13')
+    @min_os_level("10.13")
     def testConstants10_13(self):
         self.assertIsInstance(PDFBorderKeyLineWidth, unicode)
         self.assertIsInstance(PDFBorderKeyStyle, unicode)
         self.assertIsInstance(PDFBorderKeyDashPattern, unicode)
 
+
 if __name__ == "__main__":
     main()
