@@ -1,4 +1,3 @@
-
 from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 
@@ -6,13 +5,14 @@ import sys
 
 
 if sys.version_info[0] != 2:
+
     def buffer(value):
         if isinstance(value, bytes):
             return value
-        return value.encode('latin1')
+        return value.encode("latin1")
 
-class TestCGFont (TestCase):
 
+class TestCGFont(TestCase):
     def testTypes(self):
         self.assertIsCFType(CGFontRef)
 
@@ -25,7 +25,6 @@ class TestCGFont (TestCase):
         self.assertEqual(kCGFontIndexInvalid, ((1 << 16) - 1))
         self.assertEqual(kCGGlyphMax, kCGFontIndexMax)
 
-
         self.assertIsInstance(kCGFontVariationAxisName, unicode)
         self.assertIsInstance(kCGFontVariationAxisMinValue, unicode)
         self.assertIsInstance(kCGFontVariationAxisMaxValue, unicode)
@@ -34,9 +33,7 @@ class TestCGFont (TestCase):
         self.assertEqual(CGGlyphMin, 0)
         self.assertEqual(CGGlyphMax, kCGGlyphMax)
 
-
-
-    @min_os_level('10.5')
+    @min_os_level("10.5")
     # Most functions should work on 10.4 as well, except for the convenient
     # contruction functions
     def testFunctions(self):
@@ -102,22 +99,19 @@ class TestCGFont (TestCase):
         v = CGFontCanCreatePostScriptSubset(font, kCGFontPostScriptFormatType1)
         self.assertIsInstance(v, bool)
 
-
         # PyObjC doesn't wrap ATSUI, therefore we cannot actually call
         # the function.
-        #self.fail('CGFontCreateWithPlatformFont')
-        self.assertArgHasType(CGFontCreateWithPlatformFont, 0,
-                objc._C_PTR + objc._C_VOID)
+        # self.fail('CGFontCreateWithPlatformFont')
+        self.assertArgHasType(CGFontCreateWithPlatformFont, 0, objc._C_PTR + objc._C_VOID)
         self.assertResultIsCFRetained(CGFontCreateWithPlatformFont)
 
-
-        #data = open('/Library/Fonts/Webdings.ttf', 'rb').read()
-        with open('/Library/Fonts/Courier New.ttf', 'rb') as fp:
+        # data = open('/Library/Fonts/Webdings.ttf', 'rb').read()
+        # with open('/Library/Fonts/Courier New.ttf', 'rb') as fp:
+        #    data = fp.read()
+        with open("/System/Library/Fonts/Symbol.ttf", "rb") as fp:
             data = fp.read()
         self.assertResultIsCFRetained(CGFontCreateWithDataProvider)
-        font = CGFontCreateWithDataProvider(
-                CGDataProviderCreateWithCFData(buffer(data))
-        )
+        font = CGFontCreateWithDataProvider(CGDataProviderCreateWithCFData(buffer(data)))
         self.assertIsInstance(font, CGFontRef)
 
         tags = CGFontCopyTableTags(font)
@@ -132,28 +126,25 @@ class TestCGFont (TestCase):
                 continue
             self.assertIsInstance(data, CFDataRef)
 
-        v = CGFontCopyGlyphNameForGlyph(font, ord('A'))
+        v = CGFontCopyGlyphNameForGlyph(font, ord("A"))
         self.assertIsInstance(v, unicode)
 
-        glyphnames = ['chat', 'conference', 'woman' ]
+        glyphnames = ["chat", "conference", "woman"]
 
         v = CGFontGetGlyphWithGlyphName(font, glyphnames[0])
         self.assertIsInstance(v, (int, long))
 
-        glyphs = [ CGFontGetGlyphWithGlyphName(font, nm)
-                    for nm in glyphnames ]
+        glyphs = [CGFontGetGlyphWithGlyphName(font, nm) for nm in glyphnames]
 
         self.assertResultHasType(CGFontGetGlyphAdvances, objc._C_BOOL)
-        v, advances = CGFontGetGlyphAdvances(
-                font, glyphs, len(glyphs), None)
+        v, advances = CGFontGetGlyphAdvances(font, glyphs, len(glyphs), None)
         self.assertIsInstance(v, bool)
         self.assertEqual(len(advances), 3)
         for v in advances:
             self.assertIsInstance(v, (int, long))
 
         self.assertResultHasType(CGFontGetGlyphBBoxes, objc._C_BOOL)
-        v, bboxes = CGFontGetGlyphBBoxes(
-                font, glyphs, len(glyphs), None)
+        v, bboxes = CGFontGetGlyphBBoxes(font, glyphs, len(glyphs), None)
         self.assertIsInstance(v, bool)
         self.assertEqual(len(bboxes), 3)
         for v in bboxes:
@@ -161,20 +152,21 @@ class TestCGFont (TestCase):
 
         self.assertResultIsCFRetained(CGFontCreatePostScriptSubset)
         psfont = CGFontCreatePostScriptSubset(
-                font, "pyobjc-characters",
-                 kCGFontPostScriptFormatType42,
-                glyphs, len(glyphs), None)
+            font,
+            "pyobjc-characters",
+            kCGFontPostScriptFormatType42,
+            glyphs,
+            len(glyphs),
+            None,
+        )
         if psfont is not None:
             self.assertIsInstance(psfont, CFDataRef)
 
-
         self.assertResultIsCFRetained(CGFontCreatePostScriptEncoding)
-        map = glyphs + [0]*(256-len(glyphs))
-        psfont = CGFontCreatePostScriptEncoding(
-                font, map)
+        map = glyphs + [0] * (256 - len(glyphs))
+        psfont = CGFontCreatePostScriptEncoding(font, map)
         self.assertIsInstance(psfont, CFDataRef)
 
 
-
 if __name__ == "__main__":
     main()
