@@ -1,12 +1,13 @@
-
 from PyObjCTools.TestSupport import *
 from Quartz import *
 import Quartz
 import os
 
-class TestCGFunction (TestCase):
+
+class TestCGFunction(TestCase):
     def testFunctions(self):
         values = []
+
         def evaluate(info, input, output):
             values.append(input)
             return input * 4
@@ -21,18 +22,19 @@ class TestCGFunction (TestCase):
         self.assertTrue(v is func)
         CGFunctionRelease(func)
 
-
         # It is not possible to "call" a CGFunction object directly, use a
         # shading object to check that the function is actually called.
 
-        shading = CGShadingCreateAxial(CGColorSpaceCreateDeviceRGB(), (0, 0), (50, 50), func, True, True)
+        shading = CGShadingCreateAxial(
+            CGColorSpaceCreateDeviceRGB(), (0, 0), (50, 50), func, True, True
+        )
         self.assertIsInstance(shading, CGShadingRef)
 
-        url = CFURLCreateWithFileSystemPath(None,
-                "/tmp/pyobjc.test.pdf", kCFURLPOSIXPathStyle, False)
+        url = CFURLCreateWithFileSystemPath(
+            None, "/tmp/pyobjc.test.pdf", kCFURLPOSIXPathStyle, False
+        )
         self.assertIsInstance(url, CFURLRef)
-        context = CGPDFContextCreateWithURL(url,
-                ((0, 0), (1000, 1000)), None)
+        context = CGPDFContextCreateWithURL(url, ((0, 0), (1000, 1000)), None)
         self.assertIsInstance(context, CGContextRef)
         try:
             CGContextBeginPage(context, objc.NULL)
@@ -40,7 +42,8 @@ class TestCGFunction (TestCase):
             CGContextDrawShading(context, shading)
         finally:
             CGContextEndPage(context)
-            if hasattr(Quartz, 'CGPDFContextClose'): CGPDFContextClose(context)
+            if hasattr(Quartz, "CGPDFContextClose"):
+                CGPDFContextClose(context)
             if os.path.exists("/tmp/pyobjc.test.pdf"):
                 os.unlink("/tmp/pyobjc.test.pdf")
 
@@ -54,9 +57,5 @@ class TestCGFunction (TestCase):
         del func
 
 
-
-
-
-
 if __name__ == "__main__":
     main()
