@@ -1,24 +1,19 @@
-
 from PyObjCTools.TestSupport import *
 from Quartz import *
 import Quartz
 import os
 
-try:
-    long
-except NameError:
-    long = int
 
-class TestCGLayer (TestCase):
+class TestCGLayer(TestCase):
     def testTypes(self):
         self.assertIsCFType(CGLayerRef)
 
     def setUp(self):
-        url = CFURLCreateWithFileSystemPath(None,
-            "/tmp/pyobjc.test.pdf", kCFURLPOSIXPathStyle, False)
+        url = CFURLCreateWithFileSystemPath(
+            None, "/tmp/pyobjc.test.pdf", kCFURLPOSIXPathStyle, False
+        )
         self.assertIsInstance(url, CFURLRef)
-        context = CGPDFContextCreateWithURL(url,
-            ((0, 0), (1000, 1000)), None)
+        context = CGPDFContextCreateWithURL(url, ((0, 0), (1000, 1000)), None)
         self.assertIsInstance(context, CGContextRef)
         CGContextBeginPage(context, objc.NULL)
 
@@ -26,12 +21,12 @@ class TestCGLayer (TestCase):
 
     def tearDown(self):
         CGContextEndPage(self.context)
-        if hasattr(Quartz, 'CGPDFContextClose'): CGPDFContextClose(self.context)
+        if hasattr(Quartz, "CGPDFContextClose"):
+            CGPDFContextClose(self.context)
         self.context = None
         if os.path.exists("/tmp/pyobjc.test.pdf"):
             os.unlink("/tmp/pyobjc.test.pdf")
 
-
     def testFunctions(self):
         self.assertResultIsCFRetained(CGLayerCreateWithContext)
         layer = CGLayerCreateWithContext(self.context, CGSize(50, 100), None)
@@ -55,5 +50,6 @@ class TestCGLayer (TestCase):
 
         self.assertIsInstance(CGLayerGetTypeID(), (int, long))
 
+
 if __name__ == "__main__":
     main()
