@@ -1,13 +1,8 @@
-
 from PyObjCTools.TestSupport import *
 from Quartz.QuartzCore import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
 
-class TestCISampler (TestCase):
+class TestCISampler(TestCase):
     def testMethods(self):
         self.assertIsNullTerminated(CISampler.samplerWithImage_keysAndValues_)
         self.assertIsNullTerminated(CISampler.initWithImage_keysAndValues_)
@@ -20,6 +15,7 @@ class TestCISampler (TestCase):
         self.assertIsInstance(kCISamplerWrapClamp, unicode)
         self.assertIsInstance(kCISamplerFilterNearest, unicode)
         self.assertIsInstance(kCISamplerFilterLinear, unicode)
+        self.assertIsInstance(kCISamplerColorSpace, unicode)
 
 
 if __name__ == "__main__":
