@@ -1,16 +1,20 @@
-
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
-class TestCVOpenGLTextureCache (TestCase):
+
+class TestCVOpenGLTextureCache(TestCase):
     def testTypes(self):
         self.assertIsCFType(CVOpenGLTextureCacheRef)
 
     def testConstants(self):
         self.assertIsInstance(kCVOpenGLTextureCacheChromaSamplingModeKey, unicode)
         self.assertIsInstance(kCVOpenGLTextureCacheChromaSamplingModeAutomatic, unicode)
-        self.assertIsInstance(kCVOpenGLTextureCacheChromaSamplingModeHighestQuality, unicode)
-        self.assertIsInstance(kCVOpenGLTextureCacheChromaSamplingModeBestPerformance, unicode)
+        self.assertIsInstance(
+            kCVOpenGLTextureCacheChromaSamplingModeHighestQuality, unicode
+        )
+        self.assertIsInstance(
+            kCVOpenGLTextureCacheChromaSamplingModeBestPerformance, unicode
+        )
 
     @expectedFailure
     def testFunctions(self):
@@ -26,5 +30,6 @@ class TestCVOpenGLTextureCache (TestCase):
 
         CVOpenGLTextureCacheFlush
 
+
 if __name__ == "__main__":
     main()
