@@ -1,14 +1,15 @@
-
 from PyObjCTools.TestSupport import *
 from Quartz.QuartzComposer import *
 
-class TestQCCompositionPickerView (TestCase):
 
-    @min_os_level('10.5')
+class TestQCCompositionPickerView(TestCase):
+    @min_os_level("10.5")
     def testConstants(self):
-        self.assertIsInstance(QCCompositionPickerViewDidSelectCompositionNotification, unicode)
+        self.assertIsInstance(
+            QCCompositionPickerViewDidSelectCompositionNotification, unicode
+        )
 
-    @min_os_level('10.5')
+    @min_os_level("10.5")
     def testMethods(self):
         self.assertResultIsBOOL(QCCompositionPickerView.showsCompositionNames)
         self.assertArgIsBOOL(QCCompositionPickerView.setShowsCompositionNames_, 0)
