@@ -1,4 +1,3 @@
-
 from PyObjCTools.TestSupport import *
 import objc
 
@@ -8,11 +7,13 @@ try:
 except ImportError:
     pass
 
-class TestQLPreviewItem (TestCase):
-    @min_os_level('10.6')
+
+class TestQLPreviewItem(TestCase):
+    @min_os_level("10.6")
     def testClasses(self):
-        v = objc.protocolNamed('QLPreviewItem')
-        self.failUnlessIsInstance(v, objc.formal_protocol)
+        v = objc.protocolNamed("QLPreviewItem")
+        self.assertIsInstance(v, objc.formal_protocol)
+
 
 if __name__ == "__main__":
     main()
